From 39bf05d48f899612dffa07c73ac276f52820a7c9 Mon Sep 17 00:00:00 2001
From: Andreas Sturmlechner <asturm@gentoo.org>
Date: Mon, 13 Jul 2020 00:41:25 +0200
Subject: [PATCH] Use CMake's own FindBoost module to detect Boost Python

Introduces BOOSTPYTHON_VERSION_MAJOR_MINOR for packaging.

Signed-off-by: Andreas Sturmlechner <asturm@gentoo.org>
---
 CMakeLists.txt | 26 ++++++++++++--------------
 1 file changed, 12 insertions(+), 14 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index e65585fb..e07a4dc6 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -51,7 +51,8 @@ endif()
 
 include(KigConfigureChecks.cmake)
 
-find_package(BoostPython)
+set(BOOSTPYTHON_VERSION_MAJOR_MINOR python37 CACHE STRING "Version of BoostPython to feed CMake's FindBoost")
+find_package(Boost 1.70 COMPONENTS ${BOOSTPYTHON_VERSION_MAJOR_MINOR})
 
 if(KF6DocTools_FOUND)
   add_subdirectory( doc )
@@ -61,15 +62,15 @@ add_subdirectory( macros )
 add_subdirectory( data )
 add_subdirectory( pykig )
 
-if(BoostPython_FOUND)
+if(Boost_FOUND)
+  find_package(PythonLibs 3 REQUIRED)
+  include_directories(${PYTHON_INCLUDE_DIRS})
   add_subdirectory( scripting )
   add_definitions(-DKIG_ENABLE_PYTHON_SCRIPTING)
-endif(BoostPython_FOUND)
+endif()
 
 set_package_properties(
-   BoostPython PROPERTIES
-   DESCRIPTION "Python scripting support in Boost"
-   URL "https://www.boost.org/"
+   Boost PROPERTIES
    TYPE OPTIONAL
    PURPOSE "Kig can optionally use Boost.Python for Python scripting"
 )
@@ -85,9 +86,6 @@ set_package_properties(
 feature_summary(WHAT ALL FATAL_ON_MISSING_REQUIRED_PACKAGES)
 
 include_directories( ${CMAKE_SOURCE_DIR}/modes )
-if(BoostPython_FOUND)
-  include_directories(${BoostPython_INCLUDE_DIRS})
-endif(BoostPython_FOUND)
 
 # kigpart
 
@@ -225,7 +223,7 @@ ki18n_wrap_ui(kigpart_PART_SRCS
    misc/kigcoordinateprecisiondialog.ui
 )
 
-if(BoostPython_FOUND)
+if(Boost_FOUND)
   set(kigpart_PART_SRCS ${kigpart_PART_SRCS}
      modes/popup/scriptactionsprovider.cc
      scripting/newscriptwizard.cc
@@ -236,7 +234,7 @@ if(BoostPython_FOUND)
   )
 
   kde_source_files_enable_exceptions(scripting/python_scripter.cc)
-endif(BoostPython_FOUND)
+endif()
 
 
 add_library(kigpart MODULE ${kigpart_PART_SRCS})
@@ -256,9 +254,9 @@ target_link_libraries(kigpart
   KF6::Archive
 )
 
-if(BoostPython_FOUND)
-  target_link_libraries(kigpart ${BoostPython_LIBRARIES} KF6::TextEditor)
-endif(BoostPython_FOUND)
+if(Boost_FOUND)
+  target_link_libraries(kigpart Boost::${BOOSTPYTHON_VERSION_MAJOR_MINOR} ${PYTHON_LIBRARIES} KF6::TextEditor)
+endif()
 
 if (Qt${QT_MAJOR_VERSION}XmlPatterns_FOUND)
   target_link_libraries(kigpart Qt::XmlPatterns)
-- 
2.27.0

